@@ -5,7 +5,7 @@
  */
 
 #include <popper.h>
-RCSID("$Id: pop_dele.c,v 1.7 1996/10/28 16:25:22 assar Exp $");
+RCSID("$Id: pop_dele.c,v 1.8 1997/05/11 11:04:32 assar Exp $");
 
 /* 
  *  dele:   Delete a message from the POP maildrop
@@ -36,8 +36,9 @@ pop_dele (POP *p)
 
 #ifdef DEBUG
     if(p->debug)
-        pop_log(p,POP_DEBUG,"Deleting message %u at offset %u of length %u\n",
-            mp->number,mp->offset,mp->length);
+        pop_log(p, POP_DEBUG,
+		"Deleting message %u at offset %ld of length %ld\n",
+		mp->number, mp->offset, mp->length);
 #endif /* DEBUG */
 
     /*  Update the messages_deleted and bytes_deleted counters */
