@@ -1,6 +1,6 @@
 /*
- * Copyright (c) 1995, 1996 Kungliga Tekniska Hgskolan (Royal Institute
- * of Technology, Stockholm, Sweden).
+ * Copyright (c) 1995, 1996, 1997 Kungliga Tekniska Hgskolan
+ * (Royal Institute of Technology, Stockholm, Sweden).
  * All rights reserved.
  * 
  * Redistribution and use in source and binary forms, with or without
@@ -38,7 +38,7 @@
 
 #include "krb_locl.h"
 
-RCSID("$Id: kdc_reply.c,v 1.6 1996/10/27 16:29:43 joda Exp $");
+RCSID("$Id: kdc_reply.c,v 1.9 1997/04/15 21:52:14 assar Exp $");
 
 static int little_endian; /* XXX ugly */
 
@@ -62,10 +62,14 @@ kdc_reply_cred(KTEXT cip, CREDENTIALS *cred)
 	return INTK_BADPW;
     p += krb_get_string(p, cred->realm);
     
+    if(p + 3 > cip->dat + cip->length)
+	return INTK_BADPW;
     cred->lifetime = *p++;
     cred->kvno = *p++;
     cred->ticket_st.length = *p++;
     
+    if(p + cred->ticket_st.length + 4 > cip->dat + cip->length)
+	return INTK_BADPW;
     memcpy(cred->ticket_st.dat, p, cred->ticket_st.length);
     p += cred->ticket_st.length;
     
@@ -74,7 +78,8 @@ kdc_reply_cred(KTEXT cip, CREDENTIALS *cred)
     return KSUCCESS;
 }
 
-int kdc_reply_cipher(KTEXT reply, KTEXT cip)
+int
+kdc_reply_cipher(KTEXT reply, KTEXT cip)
 {
     unsigned char *p;
     unsigned char pvno;
